# == Class: testd8
#
# Installation d'un environnement LAMP sur Debian 7 avec Drupal 8
#
# === Parameters
#
# Les paramètres $1 $2 de /tmp/mysql sont respectivement le mot de passe root mysql et le mot de passe du compte drupal mysql données en paramètres dans les userdatas du script de déploiement drupal.php disponible sur le GitHub Ikoula
#
#
# === Authors
#
# Author JulienQ Ikoula contribATikoula.com
#
# === Copyright
#
# Copyright 2016 JulienQ Ikoula.
#

class lamp::install {

	exec { 'aptgetupdate':
			command => "apt-get update",
			path => "/usr/bin",
			logoutput => on_failure,
	}

	package { 'apache2':
			ensure => latest,
			require => Exec['aptgetupdate'],
	}

	package { 'mysql-server':
			ensure => latest,
			require => Package['apache2']
	}

	package { 'libapache2-mod-php5':
			ensure => latest,
			require => Package['mysql-server']
	}

	package { 'php5-mysql':
			ensure => latest,
			require => Package['libapache2-mod-php5'],
	}

	file { "/etc/apache2/sites-available/drupal.conf" :
		source => "/etc/puppet/modules/testd8/files/etc.apache2.sites-available.drupal",
		ensure => file,
		owner   => "root",
		group   => "root",
		require => Package['apache2'],
		mode    => 0644
    }
}

class drupal::install {
        exec { 'drupal':
                command => 'wget -P /var/www/ http://ftp.drupal.org/files/projects/drupal-7.41.tar.gz && tar -xvzf /var/www/drupal-7.41.tar.gz -C /var/www/ && mv /var/www/drupal-7.41 /var/www/drupal && chown -R www-data.www-data /var/www/drupal/ && rm -rf /var/www/drupal-7.41.tar.gz',
                path => [ "/usr/bin", "/bin" ],
                require => Class["lamp::install"],
        }
}
class apache::vhost {
        exec { 'drupalvhost':
                command => 'a2ensite drupal.conf && a2dissite 000-default.conf',
                path => [ "/usr/sbin", "/usr/bin" ],
                require => [
                                Class["lamp::install"],
                                Class["drupal::install"],
                                ]
        }
}
class apache::service {
        exec { 'httpreload':
                command => '/etc/init.d/apache2 reload',
                require    => Class["apache::vhost"],
        }
}
class mysql::rootpw {
        exec { 'rootpw':
                command => 'mysqladmin -u root password `awk \'{print $1}\' /tmp/mysql`',
                path => '/usr/bin',
                require => Class["lamp::install"],
                logoutput => on_failure
        }
}
class mysql::drupalbdd {
        exec { 'drupalbdd':
                command => 'mysql -u root -p`awk \'{print $1}\' /tmp/mysql` -e "CREATE DATABASE drupal;"',
                path => '/usr/bin',
                require => [Class["lamp::install"],
                                Class["mysql::rootpw"],
                                ]
        }
}
class mysql::drupalbdduser {
         exec { 'drupaluser':
                command => 'mysql -u root -p`awk \'{print $1}\' /tmp/mysql` -e "CREATE USER \'drupal\'@\'localhost\' IDENTIFIED BY \'`awk \'{print $2}\' /tmp/mysql`\';"',
                path => [ "/usr/bin", "/bin" ],
                require => [
								Class["lamp::install"],
								Class["mysql::rootpw"],
							]
        }
}
class mysql::drupalbddpriv {
        exec { 'drupalpriv':
                command => 'mysql -u root -p`awk \'{print $1}\' /tmp/mysql` -e "GRANT ALL PRIVILEGES ON drupal.* TO \'drupal\'@\'localhost\';" && rm -f /tmp/mysql',
                path => [ "/usr/bin", "/bin" ],
                require => Class["mysql::drupalbdduser"],
                logoutput => on_failure
        }
}
class mysql::service {
        service { "mysql" :
			ensure     => "running",
			enable     => "true",
			hasrestart => "true",
			hasstatus => "true",
			require    => [
							Class["lamp::install"],
							Class["mysql::drupalbdduser"],
						]
		}
}

class testd8 {
        include lamp::install, drupal::install, apache::vhost, apache::service, mysql::rootpw, mysql::drupalbdd, mysql::drupalbdduser, mysql::drupalbddpriv, mysql::service
}
